Changes
-------

0.4 (2018-05-13)
~~~~~~~~~~~~~~~~

* Add support for ``expire`` and ``retry`` parameters to the command line for
  ``priority=2`` messages
* Add support for attachments

0.3 (2016-12-29)
~~~~~~~~~~~~~~~~

* Add support for the Glances API
* Add a ``cancel`` function to ``MessageRequest`` objects to cancel high
  priority messages
* Add support for html message styling
* Fix bug in MessageRequest.poll for ``priority=2`` requests

0.2 (2014-08-16)
~~~~~~~~~~~~~~~~

* Fix bug when using current timestamp
* Add a ``pushover`` command line utility
* Add Python 3 support
* Add configuration file feature
* Easier and more compact Client class creation
* Switch to ``setuptools`` for easier installation and dependencies handling

0.1 (2013-04-16)
~~~~~~~~~~~~~~~~

Initial Release
